/*
 * ws2812.h
 *
 *  Created on: Mar 25, 2026
 *      Author: ewars
 */

#ifndef INC_WS2812_DRV_H_
#define INC_WS2812_DRV_H_

#include "stdint-gcc.h"


#define LED_N				24
#define RESET_LEN			50

#define PWM_ZERO			29
#define PWM_ONE				58


void ws2812_Init(void);
void ws2812_update(void);
void ws2812_set_colour(uint8_t led, uint8_t red, uint8_t green, uint8_t blue);
void ws2812_wait(void);
void ws2812_reset(void);
void ws2812_resetColour(uint8_t r, uint8_t g, uint8_t b);


#endif /* INC_WS2812_DRV_H_ */
